#
# spec file for package target-isns
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           target-isns
Summary:        Supplies iSNS support for Linux kernel target
License:        GPL-2.0+
Group:          System/Kernel
Version:        0.6.3
Release:        lp151.2.3
Source:         %{name}-%{version}.tar.xz
Url:            https://github.com/open-iscsi/target-isns
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  glibc-devel
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}

%description
Target-isns is an Internet Storage Name Service (iSNS) client for the
Linux LIO iSCSI target. It allows to register LIO iSCSI targets to an
iSNS server.

The iSNS protocol is specified in
[RFC 4171](http://tools.ietf.org/html/rfc4171) and its purpose is to
make easier to discover, manage, and configure iSCSI devices. With
iSNS, iSCSI targets can be registered to a central iSNS server and
initiators can be configured to discover the targets by asking the
iSNS server.

%prep
%setup -n %{name}-%{version}

%build
%cmake -DSUPPORT_SYSTEMD=ON
make

%install
cd build
make DESTDIR="%{buildroot}" install
if [ ! -d "%{buildroot}/usr/sbin" ] ; then
	mkdir -p "%{buildroot}/usr/sbin"
fi
ln -sf /usr/sbin/service "%{buildroot}/usr/sbin/rc%{name}"

%post
%{service_add_post target-isns.service}

%postun
%{service_del_postun target-isns.service}

%pre
%{service_add_pre target-isns.service}

%preun
%{service_del_preun target-isns.service}

%files
%defattr(-,root,root)
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/target-isns.conf
%{_bindir}/target-isns
%{_sbindir}/rctarget-isns
%doc COPYING README.md THANKS
%doc %{_mandir}/man8/target-isns.8%{?ext_man}
%{_unitdir}/target-isns.service

%changelog
* Thu Aug 31 2017 lduncan@suse.com
- Upgraded to version v0.6.3 from v0.6.2, replacing
  the release tarball and updating the SPEC file. (bsc#1056692)
* Tue Aug  8 2017 jengelh@inai.de
- Fix RPM groups. Replace %%__-type macro indirections and
  old $RPM shell variables.
* Tue Nov 10 2015 p.drouand@gmail.com
- Update to version 0.6.2
  * No changelog available
- Remove obsolete patches
  * target-isns-add-systemd-support.patch
  * target-isns-changes-since-v0.3.diff.bz2
  * target-isns-dont-ignore-read-return-value.patch
  * target-isns-fix-remaining-little-endian-IP-addr.patch
  * target-isns-handle-big-endian-arch.patch
  * target-isns-define-posix_c_source-for-netdb
- Remove redundant gcc and make build dependencies
- Build require systemd-rpm-macros instead of full systemd package
- Use %%cmake macro
- Remove redundant %%clean section
* Wed Oct 21 2015 lduncan@suse.com
- Handle 2 places isnsd was handling IP addresses
  incorrectly, assuming big-endian architecture (bsc#950366),
  adding two patches:
  * target-isns-handle-big-endian-arch.patch
  * target-isns-fix-remaining-little-endian-IP-addr.patch
* Mon Aug 10 2015 lduncan@suse.com
- Defined _POSIX_C_SOURCE to 2001 level to enable netdb.h
  gai_strerror and friends, fixing build issue, adding patch:
  target-isns-define-posix_c_source-for-netdb
* Fri Dec  5 2014 lduncan@suse.com
- Cleaned up spec file, added rctarget-isns symlink
* Thu Nov 13 2014 lduncan@suse.com
- Added systemd support, adding patch:
  target-isns-add-systemd-support.patch
* Thu Nov 13 2014 lduncan@suse.com
- Added all changes upstream since version 0.3, since
  I needed the man page and it's included. This also meant
  updating the spec file to list the man page.
  Added patch, taken straight from 'git diff v0.3..HEAD':
  target-isns-changes-since-v0.3.diff.bz2
* Fri Nov  7 2014 lduncan@suse.com
- update use of _BSD_SOURCE to use _DEFAULT_SOUCE, adding patch:
  target-isns-update-BSD-SOURCE-to-DEFAULT-SOURCE.patch
* Thu Sep 25 2014 lduncan@suse.com
- First attempt at importing this github project
  into OBS
